@@ -28,6 +28,13 @@ class ComponentSpecificParametersEnum:
     AZGARD_ENVPATH = "environment_path"
     AZGARD_VALUES_KEY = "values_key"
     AZGARD_DEBUG = "debug"
+
+    # ICOLOS
+    ICOLOS_CONFPATH = "configuration_path"
+    ICOLOS_EXECUTORSCRIPTPATH = "executor_script_path"
+    ICOLOS_ENVPATH = "environment_path"
+    ICOLOS_VALUES_KEY = "values_key"
+    ICOLOS_DEBUG = "debug"
     #######################
 
     RAT_PK_PROPERTY = "rat_pk_property"
