@@ -7,7 +7,7 @@ from reinvent_scoring.scoring.component_parameters import ComponentParameters
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.score_summary import ComponentSummary
 from reinvent_scoring.scoring.score_transformations import TransformationFactory
-from reinvent_scoring.scoring.enums import TransformationTypeEnum
+from reinvent_scoring.scoring.enums import TransformationTypeEnum, TransformationParametersEnum
 
 
 class PredictivePropertyComponent(BaseScoreComponent):
@@ -42,18 +42,22 @@ class PredictivePropertyComponent(BaseScoreComponent):
         return packaged_model
 
     def _apply_transformation(self, predicted_activity, parameters: dict):
-        if parameters.get(self.component_specific_parameters.TRANSFORMATION, False):
-            activity = self._transformation_function(predicted_activity, parameters)
+        transform_params = parameters.get(self.component_specific_parameters.TRANSFORMATION)
+        if transform_params:
+            activity = self._transformation_function(predicted_activity, transform_params)
         else:
             activity = predicted_activity
         return activity
 
     def _assign_transformation(self, specific_parameters: dict):
         transformation_type = TransformationTypeEnum()
-        """classification models should not have any prediction transformations"""
-        if specific_parameters[self.component_specific_parameters.SCIKIT] == "classification":
-            specific_parameters[self.component_specific_parameters.TRANSFORMATION] = False
-            specific_parameters[self.component_specific_parameters.TRANSFORMATION_TYPE] = transformation_type.NO_TRANSFORMATION
+        transform_params = specific_parameters.get(self.component_specific_parameters.TRANSFORMATION)
+        # classification models should not have any prediction transformations
+        is_classification = specific_parameters[self.component_specific_parameters.SCIKIT] == "classification"
+        if is_classification or not transform_params:
+            specific_parameters[self.component_specific_parameters.TRANSFORMATION] = {
+                    TransformationParametersEnum.TRANSFORMATION_TYPE: transformation_type.NO_TRANSFORMATION
+                }
         factory = TransformationFactory()
-        transform_function = factory.get_transformation_function(specific_parameters)
+        transform_function = factory.get_transformation_function(transform_params)
         return transform_function
