@@ -84,9 +84,7 @@ class SelectivityComponent(BaseScoreComponent):
         return transform_function
 
     def _prepare_activity_parameters(self, parameters: ComponentParameters) -> ComponentParameters:
-        model_path = parameters.specific_parameters["activity_model_path"]
         specific_parameters = parameters.specific_parameters["activity_specific_parameters"]
-        specific_parameters['model_path'] = model_path
         activity_params = ComponentParameters(name=self.parameters.name,
                                               weight=self.parameters.weight,
                                               component_type=self.parameters.component_type,
@@ -95,9 +93,7 @@ class SelectivityComponent(BaseScoreComponent):
         return activity_params
 
     def _prepare_offtarget_parameters(self, parameters: ComponentParameters) -> ComponentParameters:
-        model_path = parameters.specific_parameters["offtarget_model_path"]
         specific_parameters = parameters.specific_parameters["offtarget_specific_parameters"]
-        specific_parameters['model_path'] = model_path
         offtarget_params = ComponentParameters(name=self.parameters.name,
                                                weight=self.parameters.weight,
                                                component_type=self.parameters.component_type,
